caellion-python-commons: caellion.pycommons.hashing.file_hashing.UnsupportedAlgorithmException Class Reference

caellion-python-commons

caellion.pycommons.hashing.file_hashing.UnsupportedAlgorithmException Class Reference

This exception is raised whenever provided algorithm is not one of allowed algorithms. More...

Inheritance diagram for caellion.pycommons.hashing.file_hashing.UnsupportedAlgorithmException:

## Detailed Description

This exception is raised whenever provided algorithm is not one of allowed algorithms.

Definition at line 8 of file file_hashing.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/hashing/file_hashing.py